Function termbox::peek_event
pub fn peek_event(timeout: uint) -> Event
Get an event if within timeout milliseconds, otherwise return urn NoEvent.
pub fn peek_event(timeout: uint) -> Event
Get an event if within timeout milliseconds, otherwise return urn NoEvent.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).